package accountlogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-member-server/pkg/domain/usecase"

	"code.30cm.net/digimon/app-cloudep-member-server/gen_result/pb/member"
	"code.30cm.net/digimon/app-cloudep-member-server/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type VerifyPlatformAuthResultLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewVerifyPlatformAuthResultLogic(ctx context.Context, svcCtx *svc.ServiceContext) *VerifyPlatformAuthResultLogic {
	return &VerifyPlatformAuthResultLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// VerifyPlatformAuthResult 驗證 google 登入是否有效
func (l *VerifyPlatformAuthResultLogic) VerifyPlatformAuthResult(in *member.VerifyAuthResultReq) (*member.VerifyAuthResultResp, error) {
	result, err := l.svcCtx.AccountUseCase.VerifyPlatformAuthResult(l.ctx, usecase.VerifyAuthResultRequest{
		Account: in.GetAccount(),
		Token:   in.GetToken(),
	})
	if err != nil {
		return nil, err
	}

	return &member.VerifyAuthResultResp{
		Status: result.Status,
	}, nil
}
